@@ -19,26 +19,38 @@
 
 #include "webcam.h"
 
-/* TODO: disable if WxH != 640x480, 320x240 or 160x120 */
 
 u_long id = 1172430309;
-u_long options = BE_GFX|BEQ_PICTURE;
+u_long options = BE_GFX|BEQ_PICTURE|BEQ_BYPASS;
 char desc[] = "Webcam plugin";
 
 
 void
-create(__attribute__ ((unused)) Context_t *ctx)
+create(Context_t *ctx)
 {
+  if ((WIDTH != 640) || (HEIGHT != 480))
+    if ((WIDTH != 320) || (HEIGHT != 240))
+      if ((WIDTH != 160) || (HEIGHT != 120)) {
+	printf("[!] Webcam disabled: only 640x480, 320x240 and 160x120 modes are supported\n");
+	options |= BEQ_DISABLED;
+	return;
+      }
+
+  cap = Buffer8_new();
+  pthread_mutex_init(&mtx, NULL);
+
   parse_options();
   open_device();
 
   if (!(options & BEQ_DISABLED)) {
-    init_device();
+    int res = init_device();
 
-    if (!(options & BEQ_DISABLED)) {
-      enumerate_cids();
-      start_capturing();
-    }
+    if (!res) {
+      if (!(options & BEQ_DISABLED)) {
+	enumerate_cids();
+	start_capturing();
+      }
+    } else options |= BEQ_DISABLED;
   }
 }
 
@@ -47,9 +59,11 @@ void
 destroy(__attribute__ ((unused)) Context_t *ctx)
 {
   if (!(options & BEQ_DISABLED)) {
+    pthread_join(thr, NULL);
     stop_capturing();
     uninit_device();
     close_device();
+    Buffer8_delete(cap);
   }
 
   free(dev_name);
@@ -59,6 +73,18 @@ destroy(__attribute__ ((unused)) Context_t *ctx)
 void
 run(Context_t *ctx)
 {
-  if (!(options & BEQ_DISABLED))
-    loop(ctx);
+  static int started = 0;
+
+  if (!(options & BEQ_DISABLED)) {
+    if (!started) {
+      /* FIXME passer dans le create() */
+      pthread_create(&thr, NULL, loop, (void *)ctx);
+      started = 1;
+    }
+    else {
+      pthread_mutex_lock(&mtx);
+      Buffer8_copy(cap, passive_buffer(ctx));
+      pthread_mutex_unlock(&mtx);
+    }
+  }
 }
