@@ -26,8 +26,7 @@
  *
  */
 
-extern FILE *out;
-extern void xfwrite(const void *, size_t, size_t, FILE *);
+extern int write_exact(const u_char *, const int);
 
 
 void
@@ -36,19 +35,20 @@ v6(const Context_t *ctx)
   uint32_t proto = 6, proto2;
   uint32_t total, total2;
   Pixel_t *src;
+  int ret;
 
   /* send packet size */
   total = sizeof(uint32_t)+BUFFSIZE*3*sizeof(u_char);
   total2 = htonl(total);
-  xfwrite((const void *)&total2, sizeof(uint32_t), 1, out);
+  ret = write_exact((const u_char *)&total2, sizeof(uint32_t));
   
   /* protocol version */
   proto2 = htonl(proto);
-  xfwrite((const void *)&proto2, sizeof(uint32_t), 1, out);
+  ret = write_exact((const u_char *)&proto2, sizeof(uint32_t));
   
   /* send picture */
   src = export_RGB_active_buffer(ctx, 1);
-  xfwrite((const void *)src, sizeof(u_char), BUFFSIZE*3, out);
+  ret = write_exact((const u_char *)src, sizeof(u_char)*BUFFSIZE*3);
   xfree(src);
 }
 
