@@ -223,7 +223,7 @@ Colormaps_find(const char *name)
 long
 Colormaps_random_id()
 {
-  u_long idx = 0;
+  uint32_t idx = 0;
 
   assert(colormaps != NULL);
   
