@@ -22,6 +22,7 @@
 #include "brandom.h"
 #include "pictures.h"
 #include "colormaps.h"
+#include "sequences.h"
 
 
 #define DELAY_MIN 15
@@ -151,14 +152,39 @@ Context_delete(Context_t *ctx)
 }
 
 
+void
+Context_set_colormap(Context_t *ctx)
+{
+  /* find the cmap, if any. default cmap otherwise */
+  if (ctx->cf != NULL) {
+    ctx->cf->fader->target
+      = (ctx->sm->next->cmap_id) ?
+      Colormaps_index(ctx->sm->next->cmap_id) : 0;
+    CmapFader_set(ctx->cf);
+  }
+}
+
+
+void
+Context_set_picture(Context_t *ctx)
+{
+  /* find the picture, if any. default picture otherwise */
+  if (ctx->pf != NULL) {
+    ctx->pf->fader->target
+      = (ctx->sm->next->picture_id) ?
+      Pictures_index(ctx->sm->next->picture_id) : 0;
+    PictFader_set(ctx->pf);
+  }
+}
+
 void
 Context_set(Context_t *ctx)
 {
   GList *tmp;
 
-#ifdef DEBUG
+#ifdef XDEBUG
   printf("*** Context_set: cur sequence= %li\n", ctx->sm->cur->id);
-  printf("*** Context_set: new sequence= %li\n", ctx->sm->new->id);
+  printf("*** Context_set: next sequence= %li\n", ctx->sm->next->id);
 #endif
 
   tmp = g_list_first(ctx->sm->cur->layers);
@@ -175,21 +201,8 @@ Context_set(Context_t *ctx)
     tmp = g_list_next(tmp);
   }		
 
-  /* find the picture, if any. default picture otherwise */
-  if (ctx->pf != NULL) {
-    ctx->pf->fader->target
-      = (ctx->sm->next->picture_id) ?
-      Pictures_index(ctx->sm->next->picture_id) : 0;
-    PictFader_set(ctx->pf);
-  }
-
-  /* find the cmap, if any. default cmap otherwise */
-  if (ctx->cf != NULL) {
-    ctx->cf->fader->target
-      = (ctx->sm->next->cmap_id) ?
-      Colormaps_index(ctx->sm->next->cmap_id) : 0;
-    CmapFader_set(ctx->cf);
-  }
+  Context_set_colormap(ctx);
+  Context_set_picture(ctx);
 
   /* call on_switch_on() on new plugins */
   tmp = g_list_first(ctx->sm->next->layers);
@@ -436,6 +449,19 @@ Context_random_sequence(Context_t *ctx)
 }
 
 
+void
+Context_set_sequence(Context_t *ctx, const uint32_t id)
+{
+  Sequence_t *seq = Sequences_find(id);
+
+  assert(NULL != seq);
+  ctx->sm->curseq = seq->layers;
+  Sequence_copy(seq, ctx->sm->next);
+
+  Context_set(ctx);
+}
+
+
 void
 Context_use_bank(Context_t *ctx, const u_char bank)
 {
@@ -443,16 +469,15 @@ Context_use_bank(Context_t *ctx, const u_char bank)
 
   id = ctx->sm->banks[ctx->sm->cur_bankset][bank];
   if (id) {
-    GList *tmp = NULL;
+    Sequence_t *seq;
 
     if (libbiniou_verbose)
       printf("[s] Set sequence: %li\n", id);
 
-    tmp = Sequences_find(id);
-    assert(NULL != tmp); /* Sequences_find/1 should xerror on not found,
-			    sanity check */
-    ctx->sm->curseq = tmp;
-    Sequence_copy(tmp->data, ctx->sm->next);
+    seq = Sequences_find(id);
+    assert(NULL != seq);
+    ctx->sm->curseq = seq->layers;
+    Sequence_copy(seq, ctx->sm->next);
 
     ctx->bank = bank; /* ca sert a quoi de garder ctx->bank ? --oliv3 */
 
