@@ -93,6 +93,7 @@ typedef struct Context_s {
   char     fullscreen:1;
   char     display_colormap:1;
   char     take_screenshot:1;
+  char     bypass:1;
 
   void (*events_cb)(struct Context_s *, const BKey_t *); /* events callback */
 
@@ -104,6 +105,8 @@ Context_t *Context_new();
 void Context_delete(Context_t *);
 
 void Context_set(Context_t *);
+void Context_set_colormap(Context_t *);
+void Context_set_picture(Context_t *);
 void Context_run(Context_t *);
 void Context_update(Context_t *);
 void Context_update_auto(Context_t *);
@@ -125,7 +128,7 @@ void Context_previous_sequence(Context_t *);
 void Context_next_sequence(Context_t *);
 void Context_latest_sequence(Context_t *);
 void Context_random_sequence(Context_t *);
-void Context_set_sequence(Context_t *, const u_long);
+void Context_set_sequence(Context_t *, const uint32_t);
 
 /* Events */
 int Context_event(Context_t *, const Event_t *); /* TODO void ? */
