@@ -200,6 +200,12 @@ Context_event(Context_t *ctx, const Event_t *e)
 	ctx->params3d.do_auto_rotate = 1;
       }
       return 1;
+      break;
+
+    case BA_BYPASS:
+      ctx->bypass = !ctx->bypass;
+      return 1;
+      break;
 
     default:
       return 0;
