@@ -79,10 +79,11 @@ Context_sequence(Context_t *ctx)
     if (P == ctx->sm->cur->lens)
       push_buffer(ctx);
 
-    if (P->run != NULL) {
-      P->run(ctx);
-      P->calls++;
-    }
+    if (P->run != NULL)
+      if (!ctx->bypass || (ctx->bypass && !(*P->options & BEQ_BYPASS))) {
+	P->run(ctx);
+	P->calls++;
+      }
 
     switch (layer->mode) {
     case NONE:
@@ -124,9 +125,6 @@ Context_run(Context_t *ctx)
   Plugin_t *input = ctx->input_plugin;
   GSList *outputs = ctx->outputs;
 
-  /* Process events */
-  Context_process_events(ctx);
-
   /* Auto-change sequence */
   if (Alarm_ring(ctx->a_random)) {
     if (ctx->random_mode == BR_SCHEMES) {
@@ -208,26 +206,33 @@ Context_run(Context_t *ctx)
 	push_buffer(ctx);
     Buffer8_color_bar(active_buffer(ctx), BARSIZE);
   }
-  
+
   /* TODO: use plugin on_key callback */
   for ( ; outputs != NULL; outputs = g_slist_next(outputs)) {
     Plugin_t *output = (Plugin_t *)outputs->data;
     
-    if ((ctx->cf != NULL) && ctx->cf->refresh && (output->set_cmap != NULL)) {
+    if ((ctx->cf != NULL) && ctx->cf->refresh && (output->set_cmap != NULL))
       output->set_cmap(ctx);
-      ctx->cf->refresh = 0; /* XXX reinitialisation multiple */
-    }
-    if (output->run != NULL) { /* TODO print a warning: an output plugin without run() is a bug */
+
+    /* TODO print a warning: an output plugin without run() is a bug */
+    if (output->run != NULL) {
       output->run(ctx);
       output->calls++;
     }
   }
+  /* All outputs should have refreshed their cmap by now */
+  ctx->cf->refresh = 0;
 
+  /* Process events */
+  Context_process_events(ctx);
+
+  /* Screenshot */
   if (ctx->take_screenshot) {
     Context_screenshot(ctx);
     ctx->take_screenshot = 0;
   }
 
+  /* Restore possibly saved buffer */
   if ((ctx->sm->cur->lens != NULL) || ctx->display_colormap)
     pop_buffer(ctx);
   
