@@ -58,7 +58,8 @@ enum PluginOptions {
   BEQ_TEST       = 1 << 27, /* testing plugins */
   BEQ_DEBUG      = 1 << 28, /* for debug */
   BEQ_FIRST      = 1 << 29, /* insert plugin at the begining */
-  BEQ_FLUSH      = 1 << 30  /* clear the sequence before inserting the plugin */
+  BEQ_FLUSH      = 1 << 30, /* clear the sequence before inserting the plugin */
+  BEQ_BYPASS     = 1 << 31  /* plugin can be temporarily disabled */
 } PluginOptions_e;
 
 #define MAX_STYPES 11           /* user-selectable types */
