@@ -23,7 +23,7 @@
 #include "buffer_8bits.h"
 
 typedef struct Picture8_s {
-  long      id;
+  uint32_t  id;
   char      *name; 
   char      *dname;
   Buffer8_t *buff;
@@ -31,7 +31,7 @@ typedef struct Picture8_s {
 
 Picture8_t *Picture8_new(void);
 void Picture8_delete(Picture8_t *);
-int Picture8_load(Picture8_t *, const long, const char *, const char *);
+int Picture8_load(Picture8_t *, const uint32_t, const char *, const char *);
 void Picture8_copy(const Picture8_t *, Picture8_t *);
 
 #endif /* __BINIOU_PICTURE_8BITS_H */
