@@ -229,7 +229,7 @@ Pictures_find(const char *name)
 long
 Pictures_random_id()
 {
-  u_long idx;
+  uint32_t idx;
 
   assert(pictures != NULL);
   idx = b_rand_int_range(0, pictures->size-1);
@@ -241,7 +241,7 @@ Pictures_random_id()
 const Picture8_t *
 Pictures_random()
 {
-  u_long idx;
+  uint32_t idx;
 
   assert(pictures != NULL);
   idx = b_rand_int_range(0, pictures->size-1);
