@@ -63,7 +63,7 @@ Sequence_find_position(const Sequence_t *s, const Plugin_t *p)
 
 
 Sequence_t *
-Sequence_new(const u_long id)
+Sequence_new(const uint32_t id)
 {
   Sequence_t *s = xcalloc(1, sizeof(Sequence_t));
 
@@ -299,3 +299,10 @@ Sequence_remove(Sequence_t *s, const Plugin_t *p)
   Sequence_changed(s);
 }
 
+
+const uint8_t
+Sequence_size(const Sequence_t *seq)
+{
+  return g_list_length(seq->layers);
+}
+
