@@ -234,6 +234,9 @@ Sequence_load(const char *file)
 
     plugins_node = plugins_node->next;
   }
+
+  /* Check sequence length */
+  assert(Sequence_size(s) <= MAX_SEQ_LEN);
   
   /* Clean up */
   xmlFreeDoc(doc);
