@@ -32,7 +32,7 @@ typedef struct SequenceManager_s {
 
   /* Banks */
   u_char     cur_bankset;
-  u_long     banks[MAX_BANKS][MAX_BANKS];
+  uint32_t   banks[MAX_BANKS][MAX_BANKS];
 } SequenceManager_t;
 
 
