@@ -19,7 +19,6 @@
 
 #include "globals.h"
 #include "sequences.h"
-#include "sequence.h"
 
 
 void
@@ -94,8 +93,8 @@ Sequences_free()
 
 
 /* TODO un g_list_find */
-GList *
-Sequences_find(const u_long id)
+Sequence_t *
+Sequences_find(const uint32_t id)
 {
   GList *tmp;
 
@@ -106,12 +105,10 @@ Sequences_find(const u_long id)
     Sequence_t *s = (Sequence_t *)tmp->data;
 
     if (s->id == id)
-      return tmp;
+      return s;
 
     tmp = g_list_next(tmp);
   }
 
-  xerror("Sequence %li not found\n", id);
-
-  return NULL; /* not reached */
+  return NULL;
 }
