@@ -21,6 +21,7 @@
 #define __BINIOU_SEQUENCES_H
 
 #include "shuffler.h"
+#include "sequence.h"
 
 
 typedef struct Sequences_s {
@@ -33,6 +34,6 @@ typedef struct Sequences_s {
 void Sequences_new();
 void Sequences_free();
 
-GList *Sequences_find(const u_long);
+Sequence_t *Sequences_find(const uint32_t);
 
 #endif /* __BINIOU_SEQUENCES_H */
