@@ -154,7 +154,7 @@ void
 Spline_info(const Spline_t *s)
 {
   if (s == NULL)
-    xerror("Windows va redemarrer");
+    xerror("Windows va redemarrer\n");
   else {
     printf("[s] Spline has span: %d\n", s->span);
     printf("[s] %li control points\n", s->nb_cpoints);
