@@ -148,7 +148,7 @@ rmkdir(const char *p)
 }
 
 
-long
+uint32_t
 FNV_hash(const char* str)
 {
   const unsigned int fnv_prime = 0x811C9DC5;
@@ -160,7 +160,7 @@ FNV_hash(const char* str)
     hash ^= c;
   }
    
-  return (long)hash;
+  return (uint32_t)hash;
 }
 
 
