@@ -56,7 +56,7 @@ void rmkdir(const char *);
 #define _TO_STRING(s)           #s
 #define TO_STRING(s)            _TO_STRING(s)
 
-long FNV_hash(const char*);
+uint32_t FNV_hash(const char*);
 void ms_sleep(const u_long);
 int parse_two_shorts(const char *, const int, short *, short *);
 
